@@ -58,7 +58,7 @@ def ping(access_token):
         if e.response.status_code == 403:
             return {"status": "ERROR: INVALID ACCESS TOKEN", "error": True}
         raise Exception(e.response)
-    except Exception as e:
+    except Exception:
         return {"status": "ERROR: INVALID SERVER", "error": True}
 
 
@@ -96,7 +96,11 @@ def get_workflows(
 
 
 def get_workflow_status(workflow, access_token):
-    """Get status of previously created workflow."""
+    """Get status of previously created workflow.
+
+    :param workflow: name or id of the workflow.
+    :param access_token: access token of the current user.
+    """
     try:
         response, http_response = current_rs_api_client.api.get_workflow_status(
             workflow_id_or_name=workflow, access_token=access_token
@@ -165,7 +169,7 @@ def create_workflow_from_json(
 
     :param workflow_json: workflow specification in json format.
     :param name: name or UUID of the workflow to be started.
-    :param access_token: Access token of the current user.
+    :param access_token: access token of the current user.
     :param parameters: workflow input parameters dictionary.
     :param workflow_engine: one of the workflow engines (yadage, serial, cwl)
     :param outputs: dictionary with expected workflow outputs.
@@ -238,8 +242,6 @@ def start_workflow(workflow, access_token, parameters):
     :param access_token: access token of the current user.
     :param parameters: dict of workflow parameters to override the original
         ones (after workflow creation).
-    :param restart: boolean if workflow should be restarted on the same
-        workspace.
     """
     try:
         (response, http_response) = current_rs_api_client.api.start_workflow(
@@ -268,10 +270,10 @@ def start_workflow(workflow, access_token, parameters):
         raise e
 
 
-def upload_file(workflow_id, file_, file_name, access_token):
+def upload_file(workflow, file_, file_name, access_token):
     """Upload file to workflow workspace.
 
-    :param workflow_id: UID which identifies the workflow.
+    :param workflow: name or id which identifies the workflow.
     :param file_: content of a file that will be uploaded.
     :param file_name: name of a file that will be uploaded.
     :param access_token: access token of the current user.
@@ -280,7 +282,7 @@ def upload_file(workflow_id, file_, file_name, access_token):
 
     try:
         endpoint = current_rs_api_client.api.upload_file.operation.path_name.format(
-            workflow_id_or_name=workflow_id
+            workflow_id_or_name=workflow
         )
         http_response = requests.post(
             urljoin(get_api_url(), endpoint),
@@ -289,7 +291,9 @@ def upload_file(workflow_id, file_, file_name, access_token):
             headers={"Content-Type": "application/octet-stream"},
             verify=False,
         )
-        return http_response.json()
+        if http_response.ok:
+            return http_response.json()
+        raise Exception(http_response.json().get("message"))
     except requests.exceptions.ConnectionError:
         logging.debug("File could not be uploaded.", exc_info=True)
         raise Exception("Could not connect to the server {}".format(get_api_url()))
@@ -303,18 +307,23 @@ def upload_file(workflow_id, file_, file_name, access_token):
         logging.debug(
             "Something went wrong while connecting to the server.", exc_info=True
         )
-        raise Exception(
-            "The request to the server has failed for an " "unknown reason."
-        )
+        raise Exception("The request to the server has failed for an unknown reason.")
     except Exception as e:
         raise e
 
 
-def get_workflow_logs(workflow_id, access_token, steps=None, page=None, size=None):
-    """Get logs from a workflow engine."""
+def get_workflow_logs(workflow, access_token, steps=None, page=None, size=None):
+    """Get logs from a workflow engine.
+
+    :param workflow: name or id which identifies the workflow.
+    :param access_token: access token of the current user.
+    :param steps: list of step names to get logs for.
+    :param page: page number of returned log list.
+    :param size: page size of returned log list.
+    """
     try:
         (response, http_response) = current_rs_api_client.api.get_workflow_logs(
-            workflow_id_or_name=workflow_id,
+            workflow_id_or_name=workflow,
             steps=steps,
             access_token=access_token,
             page=page,
@@ -342,19 +351,19 @@ def get_workflow_logs(workflow_id, access_token, steps=None, page=None, size=Non
         raise e
 
 
-def download_file(workflow_id, file_name, access_token):
+def download_file(workflow, file_name, access_token):
     """Download the requested file if it exists.
 
-    :param workflow_id: UUID which identifies the workflow.
-    :param file_name: File name or path to the file requested.
-    :returns: .
+    :param workflow: name or id which identifies the workflow.
+    :param file_name: file name or path to the file requested.
+    :param access_token: access token of the current user.
     """
     try:
         from reana_client.utils import get_api_url
 
         logging.getLogger("urllib3").setLevel(logging.CRITICAL)
         endpoint = current_rs_api_client.api.download_file.operation.path_name.format(
-            workflow_id_or_name=workflow_id, file_name=file_name
+            workflow_id_or_name=workflow, file_name=file_name
         )
         http_response = requests.get(
             urljoin(get_api_url(), endpoint),
@@ -385,15 +394,15 @@ def download_file(workflow_id, file_name, access_token):
         raise e
 
 
-def delete_file(workflow_id, file_name, access_token):
+def delete_file(workflow, file_name, access_token):
     """Delete the requested file if it exists.
 
-    :param workflow_id: UUID which identifies the workflow.
-    :param file_name: File name or path to the file requested.
+    :param workflow: name or id which identifies the workflow.
+    :param file_name: file name or path to the file requested.
     """
     try:
         (response, http_response) = current_rs_api_client.api.delete_file(
-            workflow_id_or_name=workflow_id,
+            workflow_id_or_name=workflow,
             file_name=file_name,
             access_token=access_token,
         ).result()
@@ -424,16 +433,19 @@ def delete_file(workflow_id, file_name, access_token):
         raise e
 
 
-def list_files(workflow_id, access_token, page=None, size=None):
-    """Return the list of file for a given workflow workspace.
+def list_files(workflow, access_token, page=None, size=None):
+    """Return the list of files for a given workflow workspace.
 
-    :param workflow_id: UUID which identifies the workflow.
-    :returns: A list of dictionaries composed by the `name`, `size` and
+    :param workflow: name or id which identifies the workflow.
+    :param access_token: access token of the current user.
+    :param page: page number of returned file list.
+    :param size: page size of returned file list.
+    :returns: a list of dictionaries composed by the `name`, `size` and
                 `last-modified`.
     """
     try:
         (response, http_response) = current_rs_api_client.api.get_files(
-            workflow_id_or_name=workflow_id,
+            workflow_id_or_name=workflow,
             access_token=access_token,
             page=page,
             size=size,
@@ -464,9 +476,10 @@ def upload_to_server(workflow, paths, access_token):
 
     Shared e.g. by `code upload` and `inputs upload`.
 
-    :param workflow: ID of that workflow whose workspace should be
+    :param workflow: name or id of workflow whose workspace should be
         used to store the files.
-    :param paths: Absolute filepath(s) of files to be uploaded.
+    :param paths: absolute filepath(s) of files to be uploaded.
+    :param access_token: access token of the current user.
     """
     if not workflow:
         raise ValueError("Workflow name or id must be provided")
@@ -525,9 +538,7 @@ def upload_to_server(workflow, paths, access_token):
                 logging.info("Uploading '{}' ...".format(fname))
                 try:
                     upload_file(workflow, f, save_path, access_token)
-                    logging.info(
-                        "File '{}' was successfully " "uploaded.".format(fname)
-                    )
+                    logging.info("File '{}' was successfully uploaded.".format(fname))
                     if symlink:
                         save_path = "symlink:{}".format(save_path)
                     return [save_path]
@@ -537,6 +548,7 @@ def upload_to_server(workflow, paths, access_token):
                     logging.info(
                         "Something went wrong while uploading {}".format(fname)
                     )
+                    raise e
 
 
 def get_workflow_parameters(workflow, access_token):
@@ -747,8 +759,8 @@ def open_interactive_session(
 def close_interactive_session(workflow, access_token):
     """Close an interactive workflow session.
 
-    :param workflow: Workflow name to close.
-    :param access_token: Workflow owner REANA access token.
+    :param workflow: name or id of the workflow to close.
+    :param access_token: workflow owner REANA access token.
 
     :return: Gives the relative path to the interactive service.
     """
@@ -781,7 +793,7 @@ def mv_files(source, target, workflow, access_token):
 
     :param source: source filename or path.
     :param target: target filename or path.
-    :param workflow_id: UUID which identifies the workflowself.
+    :param workflow: name or id which identifies the workflow.
     :param access_token: token of user.
     """
     try:
@@ -886,7 +898,7 @@ def add_secrets(secrets, overwrite, access_token):
 def delete_secrets(secrets, access_token):
     """Delete a list of secrets.
 
-    :param secrets: List of secret names to be deleted.
+    :param secrets: list of secret names to be deleted.
     :param access_token: access token of the current user.
 
     """
